@@ -1,17 +1,14 @@
 import logging
-import sys
 
 from torch import nn
-from torch.nn.utils.rnn import pack_padded_sequence, pad_packed_sequence
+from torch.nn.utils.rnn import pack_padded_sequence
 
-from chebai.models.base import JCIBaseNet
+from chebai.models.base import ChebaiBaseNet
 
 logging.getLogger("pysmiles").setLevel(logging.CRITICAL)
 
 
-class ChemLSTM(JCIBaseNet):
-    NAME = "LSTM"
-
+class ChemLSTM(ChebaiBaseNet):
     def __init__(self, in_d, out_d, num_classes, **kwargs):
         super().__init__(num_classes, **kwargs)
         self.lstm = nn.LSTM(in_d, out_d, batch_first=True)
